<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml"/>
	<xsl:template name="NumList">
		<xsl:param name="Num"/>
		<xsl:variable name="Pos" select="((format-number($Num,'#')-2) div 3)+2"/>
		<xsl:choose>
			<xsl:when test="contains($Pos,'.')">
				<xsl:value-of select="substring-before($Pos,'.')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$Pos"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
<!--список из одной строки в несколько-->	
	<xsl:template name="tokenize">
		<xsl:param name="string" select="''"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="Nodespace"/>
		<xsl:param name="delimiters" select="' &#x9;&#xA;'"/>
		<xsl:choose>
			<xsl:when test="not($string)"/>
			<xsl:when test="not($delimiters)">
				<xsl:call-template name="_tokenize-characters">
					<xsl:with-param name="string" select="$string"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_tokenize-delimiters">
					<xsl:with-param name="string" select="$string"/>
					<xsl:with-param name="delimiters" select="$delimiters"/>
					<xsl:with-param name="NodeName" select="$NodeName"/>
					<xsl:with-param name="Nodespace"  select="$Nodespace"/>					
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="_tokenize-characters">
		<xsl:param name="string"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="Nodespace"/>
		<xsl:if test="$string">
			<node><xsl:value-of select="substring($string, 1, 1)"/></node>
			<xsl:call-template name="_tokenize-characters">
				<xsl:with-param name="string" select="substring($string, 2)"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="_tokenize-delimiters" >
		<xsl:param name="string"/>
		<xsl:param name="delimiters"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="Nodespace"/>
		<xsl:variable name="delimiter" select="substring($delimiters, 1, 1)"/>
		<xsl:choose>
			<xsl:when test="not($delimiter)">
				<xsl:element name="{$NodeName}"  namespace="{$Nodespace}">
					<xsl:value-of select="$string"/>
				</xsl:element>	
			</xsl:when>
			<xsl:when test="contains($string, $delimiter)">
				<xsl:if test="not(starts-with($string, $delimiter))">
					<xsl:call-template name="_tokenize-delimiters">
						<xsl:with-param name="string" select="substring-before($string, $delimiter)"/>
						<xsl:with-param name="delimiters" select="substring($delimiters, 2)"/>
						<xsl:with-param name="NodeName" select="$NodeName"/>
						<xsl:with-param name="Nodespace"  select="$Nodespace"/>	
					</xsl:call-template>
				</xsl:if>
				<xsl:call-template name="_tokenize-delimiters">
					<xsl:with-param name="string" select="substring-after($string, $delimiter)"/>
					<xsl:with-param name="delimiters" select="$delimiters"/>
					<xsl:with-param name="NodeName" select="$NodeName"/>
					<xsl:with-param name="Nodespace"  select="$Nodespace"/>						
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_tokenize-delimiters">
					<xsl:with-param name="string" select="$string"/>
					<xsl:with-param name="delimiters" select="substring($delimiters, 2)"/>
					<xsl:with-param name="NodeName" select="$NodeName"/>
					<xsl:with-param name="Nodespace"  select="$Nodespace"/>						
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
<xsl:template name="SplitTextBySpaceSp">
    <xsl:param name="Text"/>
    <xsl:param name="Len"/>
    <xsl:choose>
      <xsl:when test="string-length($Text)&lt;$Len">
        <xsl:value-of select="$Text"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="sSubstring">
          <xsl:choose>
            <xsl:when test="starts-with($Text, ' ')">
              <xsl:value-of select="string(' ')"/>
            </xsl:when>
            <xsl:when test="contains($Text, ' ')">
              <xsl:value-of select="concat(substring-before($Text,' '),' ')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="substring($Text,1, $Len)"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <xsl:variable name="TextBefore" select="$sSubstring"/>
        <xsl:variable name="TextBeforeLen" select="string-length($TextBefore)"/>
        <xsl:if test="$TextBeforeLen &lt;= $Len">
          <xsl:variable name="TextAfter" select="substring($Text,$TextBeforeLen+1)"/>
          <xsl:value-of select="$TextBefore"/>
          <xsl:if test="($Len - $TextBeforeLen) >0 and contains($TextAfter, ' ')">
            <xsl:variable name="sResultAfter">
              <xsl:call-template name="SplitTextBySpaceSp">
                <xsl:with-param name="Text" select="$TextAfter"/>
                <xsl:with-param name="Len" select="$Len - $TextBeforeLen"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:value-of select="$sResultAfter"/>
          </xsl:if>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
<!--загрузка из xml таможенного формата-->
<xsl:template name="GoodsDescr250">
		<xsl:param name="DesGoods"/>
		<xsl:param name="NodeName"/>
		<xsl:param name="Namsp"/> 
		<xsl:param name="LenDes"/>
		<xsl:variable name="DesGr">
			<xsl:call-template name="SplitTextBySpaceSp">
				<xsl:with-param name="Text" select="$DesGoods"/>
				<xsl:with-param name="Len"  select="$LenDes"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:element name="{$NodeName}"  namespace="{$Namsp}">
			<xsl:value-of select="normalize-space($DesGr)"/>
		</xsl:element>
		<xsl:variable name="DesGr1" select="substring($DesGoods,string-length($DesGr)+1)"/>
		<xsl:if test="string-length($DesGr1)>0">
			<xsl:call-template name="GoodsDescr250">
				<xsl:with-param name="DesGoods" select="$DesGr1"/>
				<xsl:with-param name="NodeName" select="$NodeName"/>
				<xsl:with-param name="Namsp" select="$Namsp"/> 
				<xsl:with-param name="LenDes" select="$LenDes"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

 <xsl:template match="*|/">
	<xsl:apply-templates select="//DCL/DCL_ITEM"/>
</xsl:template>
	<xsl:template name="GoodsGr" xmlns="urn:customs.ru:Information:CustomsDocuments:ESADout_CU:5.11.0" xmlns:clt_ru="urn:customs.ru:CommonLeafTypes:5.10.0" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.10.0" xmlns:catESAD_cu="urn:customs.ru:CUESADCommonAggregateTypesCust:5.11.0" xmlns:cltESAD_cu="urn:customs.ru:CUESADCommonLeafTypes:5.10.0" >
		<xsl:param name="AddText"/>
		<xsl:param name="FlgAllField"/>
		<catESAD_cu:GoodsGroupDescription>
			<xsl:call-template name="GoodsDescr250">
				<xsl:with-param name="DesGoods" select="$AddText"/>
				<xsl:with-param name="NodeName" select="'catESAD_cu:GoodsDescription'"/>
				<xsl:with-param name="Namsp" select="'urn:customs.ru:CUESADCommonAggregateTypesCust:5.11.0'"/> 
				<xsl:with-param name="LenDes" select="250"/>											
			</xsl:call-template>
			<xsl:if test="$FlgAllField=1">	
				<catESAD_cu:GoodsGroupInformation>
				<xsl:if test="string-length(G31_11)>0">
					<catESAD_cu:Manufacturer><xsl:value-of select="G31_11"/></catESAD_cu:Manufacturer>
				</xsl:if>
				<xsl:if test="string-length(G31_12)>0">													
					<catESAD_cu:TradeMark><xsl:value-of select="G31_12"/></catESAD_cu:TradeMark>
				</xsl:if>
				<xsl:if test="string-length(G31_14)>0">
					<catESAD_cu:GoodsMark><xsl:value-of select="G31_14"/></catESAD_cu:GoodsMark>
				</xsl:if>
				<xsl:if test="string-length(G31_14_2)>0">	
					<catESAD_cu:GoodsModel><xsl:value-of select="G31_14_2"/></catESAD_cu:GoodsModel>
				</xsl:if>
				<xsl:if test="string-length(G31_15)>0">	
					<catESAD_cu:GoodsMarking><xsl:value-of select="G31_15"/></catESAD_cu:GoodsMarking>
				</xsl:if>
				<xsl:if test="string-length(G31_16)>0">	
					<catESAD_cu:GoodsStandard><xsl:value-of select="G31_16"/></catESAD_cu:GoodsStandard>
				</xsl:if>
				<xsl:if test="string-length(G31_17)>0">	
					<catESAD_cu:GoodsSort><xsl:value-of select="G31_17"/></catESAD_cu:GoodsSort>
				</xsl:if>
				<xsl:if test="string-length(G31_18)>0">	
					<catESAD_cu:WoodSortiment><xsl:value-of select="G31_18"/></catESAD_cu:WoodSortiment>
				</xsl:if>
				<xsl:if test="string-length(G31_19)>0">	
					<catESAD_cu:WoodKind><xsl:value-of select="G31_19"/></catESAD_cu:WoodKind>
				</xsl:if>
				<xsl:if test="string-length(G31_20)>0">	
					<catESAD_cu:Dimensions><xsl:value-of select="G31_20"/></catESAD_cu:Dimensions>
				</xsl:if>													
				<xsl:if test="string-length(ISSUEDATE)>0">
					<catESAD_cu:DateIssue><xsl:value-of select="substring(ISSUEDATE,1,10)"/></catESAD_cu:DateIssue>
				</xsl:if>
				<xsl:if test="string-length(SERIALNUMBERS)>0">
					<xsl:call-template name="tokenize">
						<xsl:with-param name="string" select="SERIALNUMBERS"/>		
						<xsl:with-param name="NodeName" select="'catESAD_cu:SerialNumber'"/>
						<xsl:with-param name="Nodespace" select="'urn:customs.ru:CUESADCommonAggregateTypesCust:5.11.0'"/>
						<xsl:with-param name="delimiters" select="','"/>
					</xsl:call-template>
				</xsl:if>	
				<catESAD_cu:GoodsGroupQuantity>
					<cat_ru:GoodsQuantity><xsl:value-of select="QUANTITY"/></cat_ru:GoodsQuantity>
					<cat_ru:MeasureUnitQualifierName><xsl:value-of select="UNIT_NAME"/></cat_ru:MeasureUnitQualifierName>
					<cat_ru:MeasureUnitQualifierCode><xsl:value-of select="UNIT_CODE"/></cat_ru:MeasureUnitQualifierCode>
				</catESAD_cu:GoodsGroupQuantity>
			</catESAD_cu:GoodsGroupInformation>
			</xsl:if>	
		</catESAD_cu:GoodsGroupDescription>
	</xsl:template>	
  <xsl:template match="DCL/DCL_ITEM">
		<ED_Container xmlns ="urn:customs.ru:Information:ExchangeDocuments:ED_Container:5.10.0" xmlns:clt_ru="urn:customs.ru:CommonLeafTypes:5.10.0" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.10.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" DocumentModeID="1006058E">
			<cat_ru:DocumentID>00000000-0000-0000-0000-00000000000</cat_ru:DocumentID>
			<ContainerDoc>
				<DocBody>
					<ESADout_CU xmlns="urn:customs.ru:Information:CustomsDocuments:ESADout_CU:5.11.0" xmlns:clt_ru="urn:customs.ru:CommonLeafTypes:5.10.0" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.10.0" xmlns:catESAD_cu="urn:customs.ru:CUESADCommonAggregateTypesCust:5.11.0" xmlns:cltESAD_cu="urn:customs.ru:CUESADCommonLeafTypes:5.10.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" DocumentModeID="1006107E">
						<cat_ru:DocumentID>00000000-0000-0000-0000-00000000000</cat_ru:DocumentID>		
						<CustomsProcedure><xsl:value-of select="G011"/></CustomsProcedure>
						<CustomsModeCode><xsl:value-of select="G012"/></CustomsModeCode>
						<xsl:if test="string-length(G0131)>0">
							<TransitDirectionCode><xsl:value-of select="G0131"/></TransitDirectionCode>
						</xsl:if>
						<xsl:if test="string-length(G07_CODE)>0">
							<DeclarationKind><xsl:value-of select="G07_CODE"/></DeclarationKind>
						</xsl:if>	
						<RecipientCountryCode><xsl:value-of select="G17A"/></RecipientCountryCode>
						<ESADout_CUGoodsShipment>
							<catESAD_cu:OriginCountryName><xsl:value-of select="G16"/></catESAD_cu:OriginCountryName>
							<catESAD_cu:TotalGoodsNumber><xsl:value-of select="G05"/></catESAD_cu:TotalGoodsNumber>
							<catESAD_cu:TotalPackageNumber><xsl:value-of select="G06"/></catESAD_cu:TotalPackageNumber>
							<catESAD_cu:TotalCustCost><xsl:value-of select="format-number(G12,'0.00')"/></catESAD_cu:TotalCustCost>
							<catESAD_cu:CustCostCurrencyCode><xsl:value-of select="G121"/></catESAD_cu:CustCostCurrencyCode>
							<ESADout_CUConsignor>
								<cat_ru:OrganizationName><xsl:value-of select="G022"/></cat_ru:OrganizationName>
								<xsl:choose>
									<xsl:when test="G0231='RU'">
										<cat_ru:RFOrganizationFeatures>
											<xsl:if  test="string-length(G020)>0">
												<cat_ru:OGRN><xsl:value-of select="G020"/></cat_ru:OGRN>
											</xsl:if>
											<xsl:if  test="string-length(G021)>0">
												<cat_ru:INN><xsl:value-of select="G021"/></cat_ru:INN>
											</xsl:if>	
											<xsl:if  test="string-length(G027)>0">
												<cat_ru:KPP><xsl:value-of select="G027"/></cat_ru:KPP>
											</xsl:if>
										</cat_ru:RFOrganizationFeatures>
									</xsl:when>
									<xsl:when test="G0231='KZ'">										
										<cat_ru:RKOrganizationFeatures>
											<xsl:if  test="string-length(G020)>0">
												<cat_ru:BIN><xsl:value-of select="G020"/></cat_ru:BIN>
											</xsl:if>	
											<xsl:if  test="string-length(G021)>0">
												<cat_ru:IIN><xsl:value-of select="G021"/></cat_ru:IIN>
											</xsl:if>	
										</cat_ru:RKOrganizationFeatures>
									</xsl:when>	
									<xsl:when test="G0231='BY'">
										<cat_ru:RBOrganizationFeatures>
											<xsl:if  test="string-length(G021)>0">
												<cat_ru:UNP><xsl:value-of select="G021"/></cat_ru:UNP>
											</xsl:if>	
										</cat_ru:RBOrganizationFeatures>
									</xsl:when>
								</xsl:choose>
								<xsl:if test="string-length(G023POST)>0 or string-length(G0231)>0 or string-length(G0231N)>0 or string-length(G023SUBD)>0 or string-length(G023CITY)>0 or string-length(G023STREET)>0">
									<cat_ru:Address>
										<xsl:if test="string-length(G023POST)>0">
											<cat_ru:PostalCode><xsl:value-of select="G023POST"/></cat_ru:PostalCode>
										</xsl:if>	
										<xsl:if test="string-length(G0231)>0">
											<cat_ru:CountryCode><xsl:value-of select="G0231"/></cat_ru:CountryCode>
										</xsl:if>	
										<xsl:if test="string-length(G0231N)>0">
											<cat_ru:CounryName><xsl:value-of select="G0231N"/></cat_ru:CounryName>
										</xsl:if>											
										<xsl:if test="string-length(G023SUBD)>0">
											<cat_ru:Region><xsl:value-of select="G023SUBD"/></cat_ru:Region>
										</xsl:if>	
										<xsl:if test="string-length(G023CITY)>0">
											<cat_ru:City><xsl:value-of select="G023CITY"/></cat_ru:City>
										</xsl:if>	
										<xsl:if test="string-length(G023STREET)>0">
											<cat_ru:StreetHouse><xsl:value-of select="G023STREET"/></cat_ru:StreetHouse>
										</xsl:if>												
									</cat_ru:Address>
								</xsl:if>
							</ESADout_CUConsignor>
							<ESADout_CUConsignee>
								<cat_ru:OrganizationName><xsl:value-of select="G082"/></cat_ru:OrganizationName>
									<xsl:choose>
									<xsl:when test="G0831='RU'">
										<cat_ru:RFOrganizationFeatures>
											<xsl:if  test="string-length(G080)>0">
												<cat_ru:OGRN><xsl:value-of select="G080"/></cat_ru:OGRN>
											</xsl:if>
											<xsl:if  test="string-length(G081)>0">
												<cat_ru:INN><xsl:value-of select="G081"/></cat_ru:INN>
											</xsl:if>	
											<xsl:if  test="string-length(G087)>0">
												<cat_ru:KPP><xsl:value-of select="G087"/></cat_ru:KPP>
											</xsl:if>
										</cat_ru:RFOrganizationFeatures>
									</xsl:when>
									<xsl:when test="G0831='KZ'">										
										<cat_ru:RKOrganizationFeatures>
											<xsl:if  test="string-length(G080)>0">
												<cat_ru:BIN><xsl:value-of select="G080"/></cat_ru:BIN>
											</xsl:if>	
											<xsl:if  test="string-length(G081)>0">
												<cat_ru:IIN><xsl:value-of select="G081"/></cat_ru:IIN>
											</xsl:if>	
										</cat_ru:RKOrganizationFeatures>
									</xsl:when>	
									<xsl:when test="G0831='BY'">
										<cat_ru:RBOrganizationFeatures>
											<xsl:if  test="string-length(G081)>0">
												<cat_ru:UNP><xsl:value-of select="G081"/></cat_ru:UNP>
											</xsl:if>	
										</cat_ru:RBOrganizationFeatures>
									</xsl:when>
								</xsl:choose>
								<xsl:if test="string-length(G083POST)>0 or string-length(G0831)>0 or string-length(G0831N)>0 or string-length(G083SUBD)>0 or string-length(G083CITY)>0 or string-length(G083STREET)>0">
									<cat_ru:Address>
										<xsl:if test="string-length(G083POST)>0">
											<cat_ru:PostalCode><xsl:value-of select="G083POST"/></cat_ru:PostalCode>
										</xsl:if>	
										<xsl:if test="string-length(G0831)>0">
											<cat_ru:CountryCode><xsl:value-of select="G0831"/></cat_ru:CountryCode>
										</xsl:if>	
										<xsl:if test="string-length(G0831N)>0">
											<cat_ru:CounryName><xsl:value-of select="G0831N"/></cat_ru:CounryName>
										</xsl:if>											
										<xsl:if test="string-length(G083SUBD)>0">
											<cat_ru:Region><xsl:value-of select="G083SUBD"/></cat_ru:Region>
										</xsl:if>	
										<xsl:if test="string-length(G083CITY)>0">
											<cat_ru:City><xsl:value-of select="G083CITY"/></cat_ru:City>
										</xsl:if>	
										<xsl:if test="string-length(G083STREET)>0">
											<cat_ru:StreetHouse><xsl:value-of select="G083STREET"/></cat_ru:StreetHouse>
										</xsl:if>												
									</cat_ru:Address>
								</xsl:if>
							</ESADout_CUConsignee>
							<ESADout_CUFinancialAdjustingResponsiblePerson>
								<cat_ru:OrganizationName><xsl:value-of select="G092"/></cat_ru:OrganizationName>
								<xsl:choose>
									<xsl:when test="G0931='RU'">
										<cat_ru:RFOrganizationFeatures>
											<xsl:if  test="string-length(G090)>0">
												<cat_ru:OGRN><xsl:value-of select="G090"/></cat_ru:OGRN>
											</xsl:if>
											<xsl:if  test="string-length(G091)>0">
												<cat_ru:INN><xsl:value-of select="G091"/></cat_ru:INN>
											</xsl:if>	
											<xsl:if  test="string-length(G097)>0">
												<cat_ru:KPP><xsl:value-of select="G097"/></cat_ru:KPP>
											</xsl:if>
										</cat_ru:RFOrganizationFeatures>
									</xsl:when>
									<xsl:when test="G0931='KZ'">										
										<cat_ru:RKOrganizationFeatures>
											<xsl:if  test="string-length(G090)>0">
												<cat_ru:BIN><xsl:value-of select="G090"/></cat_ru:BIN>
											</xsl:if>	
											<xsl:if  test="string-length(G091)>0">
												<cat_ru:IIN><xsl:value-of select="G091"/></cat_ru:IIN>
											</xsl:if>	
										</cat_ru:RKOrganizationFeatures>
									</xsl:when>	
									<xsl:when test="G0931='BY'">
										<cat_ru:RBOrganizationFeatures>
											<xsl:if  test="string-length(G091)>0">
												<cat_ru:UNP><xsl:value-of select="G091"/></cat_ru:UNP>
											</xsl:if>	
										</cat_ru:RBOrganizationFeatures>
									</xsl:when>
								</xsl:choose>
								<xsl:if test="string-length(G093POST)>0 or string-length(G0931)>0 or string-length(G0931N)>0 or string-length(G093SUBD)>0 or string-length(G093CITY)>0 or string-length(G093STREET)>0">
									<cat_ru:Address>
										<xsl:if test="string-length(G093POST)>0">
											<cat_ru:PostalCode><xsl:value-of select="G093POST"/></cat_ru:PostalCode>
										</xsl:if>	
										<xsl:if test="string-length(G0931)>0">
											<cat_ru:CountryCode><xsl:value-of select="G0931"/></cat_ru:CountryCode>
										</xsl:if>	
										<xsl:if test="string-length(G0931N)>0">
											<cat_ru:CounryName><xsl:value-of select="G0931N"/></cat_ru:CounryName>
										</xsl:if>											
										<xsl:if test="string-length(G093SUBD)>0">
											<cat_ru:Region><xsl:value-of select="G093SUBD"/></cat_ru:Region>
										</xsl:if>	
										<xsl:if test="string-length(G093CITY)>0">
											<cat_ru:City><xsl:value-of select="G093CITY"/></cat_ru:City>
										</xsl:if>	
										<xsl:if test="string-length(G093STREET)>0">
											<cat_ru:StreetHouse><xsl:value-of select="G093STREET"/></cat_ru:StreetHouse>
										</xsl:if>												
									</cat_ru:Address>
								</xsl:if>
							</ESADout_CUFinancialAdjustingResponsiblePerson>		
							<xsl:if test="string-length(G142)>0 or string-length(M141)>0 or string-length(G143POST)>0 or string-length(G1431)>0 or string-length(G1431N)>0 or string-length(G143SUBD)>0 or string-length(G143CITY)>0 or string-length(G143STREET)>0">
								<ESADout_CUDeclarant>
									<cat_ru:OrganizationName><xsl:value-of select="G142"/></cat_ru:OrganizationName>
									<xsl:choose>
										<xsl:when test="G1431='RU'">
											<cat_ru:RFOrganizationFeatures>
												<xsl:if  test="string-length(G140)>0">
													<cat_ru:OGRN><xsl:value-of select="G140"/></cat_ru:OGRN>
												</xsl:if>
												<xsl:if  test="string-length(M141)>0">
													<cat_ru:INN><xsl:value-of select="M141"/></cat_ru:INN>
												</xsl:if>	
												<xsl:if  test="string-length(G147)>0">
													<cat_ru:KPP><xsl:value-of select="G147"/></cat_ru:KPP>
												</xsl:if>
											</cat_ru:RFOrganizationFeatures>
										</xsl:when>
										<xsl:when test="G1431='KZ'">										
											<cat_ru:RKOrganizationFeatures>
												<xsl:if  test="string-length(G140)>0">
													<cat_ru:BIN><xsl:value-of select="G140"/></cat_ru:BIN>
												</xsl:if>	
												<xsl:if  test="string-length(M141)>0">
													<cat_ru:IIN><xsl:value-of select="M141"/></cat_ru:IIN>
												</xsl:if>	
											</cat_ru:RKOrganizationFeatures>
										</xsl:when>	
										<xsl:when test="G1431='BY'">
											<cat_ru:RBOrganizationFeatures>
												<xsl:if  test="string-length(M141)>0">
													<cat_ru:UNP><xsl:value-of select="M141"/></cat_ru:UNP>
												</xsl:if>	
											</cat_ru:RBOrganizationFeatures>
										</xsl:when>
									</xsl:choose>
									<xsl:if test="string-length(G143POST)>0 or string-length(G1431)>0 or string-length(G1431N)>0 or string-length(G143SUBD)>0 or string-length(G143CITY)>0 or string-length(G143STREET)>0">
										<cat_ru:Address>
											<xsl:if test="string-length(G143POST)>0">
												<cat_ru:PostalCode><xsl:value-of select="G143POST"/></cat_ru:PostalCode>
											</xsl:if>	
											<xsl:if test="string-length(G1431)>0">
												<cat_ru:CountryCode><xsl:value-of select="G1431"/></cat_ru:CountryCode>
											</xsl:if>	
											<xsl:if test="string-length(G1431N)>0">
												<cat_ru:CounryName><xsl:value-of select="G1431N"/></cat_ru:CounryName>
											</xsl:if>											
											<xsl:if test="string-length(G143SUBD)>0">
												<cat_ru:Region><xsl:value-of select="G143SUBD"/></cat_ru:Region>
											</xsl:if>	
											<xsl:if test="string-length(G143CITY)>0">
												<cat_ru:City><xsl:value-of select="G143CITY"/></cat_ru:City>
											</xsl:if>	
											<xsl:if test="string-length(G143STREET)>0">
												<cat_ru:StreetHouse><xsl:value-of select="G143STREET"/></cat_ru:StreetHouse>
											</xsl:if>												
										</cat_ru:Address>
									</xsl:if>							
								</ESADout_CUDeclarant>
							</xsl:if>		
							<ESADout_CUFilledPerson>
								<xsl:choose>
									<xsl:when test="string-length(G5441)>0 and string-length(G5441NAME)>0">
										<cat_ru:PersonSurname><xsl:value-of select="G5441"/></cat_ru:PersonSurname>
										<cat_ru:PersonName><xsl:value-of select="G5441NAME"/></cat_ru:PersonName>
										<xsl:if test="string-length(G5441MDLNAME)>0">
											<cat_ru:PersonMiddleName><xsl:value-of select="G5441MDLNAME"/></cat_ru:PersonMiddleName>
										</xsl:if>
									</xsl:when>
									<xsl:otherwise>
										<cat_ru:PersonSurname>N</cat_ru:PersonSurname>
										<cat_ru:PersonName>N</cat_ru:PersonName>
									</xsl:otherwise>
								</xsl:choose>
								<catESAD_cu:ExecutionDate>
									<xsl:choose>
										<xsl:when test="string-length(G542)>0">
											<xsl:value-of select="substring(G542,1,10)"/>
										</xsl:when>
										<xsl:otherwise>2012-01-01</xsl:otherwise>	
									</xsl:choose>
								</catESAD_cu:ExecutionDate>
							</ESADout_CUFilledPerson>
							<ESADout_CUGoodsLocation>
								<xsl:if test="string-length(G300)>0">
									<InformationTypeCode><xsl:value-of select="G300"/></InformationTypeCode>
								</xsl:if>
								<xsl:if test="string-length(G3012)>0">
									<CustomsOffice><xsl:value-of select="G3012"/></CustomsOffice>
								</xsl:if>	
								<xsl:choose>
									<xsl:when test="substring(G3012,1,2)='10' or substring(G3012,1,2)='12' or substring(G3012,1,2)='1F'">
										<CustomsCountryCode>RU</CustomsCountryCode>
									</xsl:when>
									<xsl:when test="substring(G3012,1,3)='112' or substring(G3012,1,3)='240'">
										<CustomsCountryCode>BY</CustomsCountryCode>
									</xsl:when>
									<xsl:when test="substring(G3012,1,3)='398'">
										<CustomsCountryCode>KZ</CustomsCountryCode>
									</xsl:when>									
									<xsl:when test="substring(G3012,1,2)='46'">
										<CustomsCountryCode>KG</CustomsCountryCode>
									</xsl:when>									
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="substring(G3012,1,3)='112' or substring(G3012,1,3)='240'">
										<GoodsLocationPlace>
											<catESAD_cu:NumberCustomsZone><xsl:value-of select="G301"/></catESAD_cu:NumberCustomsZone>
										</GoodsLocationPlace>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="string-length(G30)>0 or string-length(G301)>0 or string-length(G3011)>0 or string-length(G3010)>0">
											<GoodsLocationWarehouse>
												<xsl:if test="string-length(G30)>0">
													<cat_ru:PrDocumentName><xsl:value-of select="G30"/></cat_ru:PrDocumentName>
												</xsl:if>	
												<xsl:if test="string-length(G301)>0">
													<cat_ru:PrDocumentNumber><xsl:value-of select="G301"/></cat_ru:PrDocumentNumber>
												</xsl:if>														
												<xsl:if test="string-length(G3011)>0">
													<cat_ru:PrDocumentDate><xsl:value-of select="substring(G3011,1,10)"/></cat_ru:PrDocumentDate>
												</xsl:if>														
												<xsl:if test="string-length(G3010)>0">
													<DocumentModeCode><xsl:value-of select="G3010"/></DocumentModeCode>
												</xsl:if>	
											</GoodsLocationWarehouse>
										</xsl:if>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="string-length(G3012)>0 or string-length(G30POST)>0 or string-length(G30SUBD)>0 or string-length(G30CITY)>0 or string-length(G30STREET)>0">
									<Address>
										<xsl:choose>
											<xsl:when test="substring(G3012,1,2)='10' or substring(G3012,1,2)='12' or substring(G3012,1,2)='1F'">
												<cat_ru:CountryCode>RU</cat_ru:CountryCode>
											</xsl:when>
											<xsl:when test="substring(G3012,1,3)='112' or substring(G3012,1,3)='240'">
												<cat_ru:CountryCode>BY</cat_ru:CountryCode>
											</xsl:when>
											<xsl:when test="substring(G3012,1,3)='398'">
												<cat_ru:CountryCode>KZ</cat_ru:CountryCode>
											</xsl:when>									
											<xsl:when test="substring(G3012,1,2)='46'">
												<cat_ru:CountryCode>KG</cat_ru:CountryCode>
											</xsl:when>									
										</xsl:choose>
										<xsl:if test="string-length(G30POST)>0">
												<cat_ru:PostalCode><xsl:value-of select="G30POST"/></cat_ru:PostalCode>
											</xsl:if>
										<xsl:if test="string-length(G30SUBD)>0">
											<cat_ru:Region><xsl:value-of select="G30SUBD"/></cat_ru:Region>
										</xsl:if>
										<xsl:if test="string-length(G30CITY)>0">										
											<cat_ru:City><xsl:value-of select="G30CITY"/></cat_ru:City>
										</xsl:if>
										<xsl:if test="string-length(G30STREET)>0">
											<cat_ru:StreetHouse><xsl:value-of select="G30STREET"/></cat_ru:StreetHouse>
										</xsl:if>
									</Address>
								</xsl:if>	
							</ESADout_CUGoodsLocation>
							<ESADout_CUConsigment>
								<catESAD_cu:ContainerIndicator>
									<xsl:choose>
										<xsl:when test="count(//DCL_LOAD_CONT/DCL_LOAD_CONT_ITEM[string-length(cont_num)>0])>0">1</xsl:when>
										<xsl:otherwise>0</xsl:otherwise>
									</xsl:choose>
								</catESAD_cu:ContainerIndicator>
								<catESAD_cu:DispatchCountryCode><xsl:value-of select="G15A"/></catESAD_cu:DispatchCountryCode>
								<catESAD_cu:DispatchCountryName><xsl:value-of select="G15"/></catESAD_cu:DispatchCountryName>
								<catESAD_cu:DestinationCountryCode><xsl:value-of select="G17A"/></catESAD_cu:DestinationCountryCode>
								<catESAD_cu:DestinationCountryName><xsl:value-of select="G17B"/></catESAD_cu:DestinationCountryName>
								<xsl:if test="string-length(G29)>0 or string-length(M29)>0">
									<catESAD_cu:BorderCustomsOffice>
										<xsl:if test="string-length(G29)>0">
											<cat_ru:Code>
												<xsl:choose>
													<xsl:when test="substring(G29,1,3)='398'">
														<xsl:value-of select="substring(G29,4,5)"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="G29"/>
													</xsl:otherwise>	
												</xsl:choose>	
											</cat_ru:Code>
										</xsl:if>	
										<xsl:if test="string-length(M29)>0">										
											<cat_ru:OfficeName><xsl:value-of select="M29"/></cat_ru:OfficeName>	
										</xsl:if>	
										<xsl:choose>
											<xsl:when test="substring(G29,1,2)='10' or substring(G29,1,2)='12' or substring(G29,1,2)='1F'">
												<cat_ru:CustomsCountryCode>643</cat_ru:CustomsCountryCode>
											</xsl:when>
											<xsl:when test="substring(G29,1,3)='112' or substring(G29,1,3)='240'">
												<cat_ru:CustomsCountryCode>112</cat_ru:CustomsCountryCode>
											</xsl:when>
											<xsl:when test="substring(G29,1,3)='398'">
												<cat_ru:CustomsCountryCode>398</cat_ru:CustomsCountryCode>
											</xsl:when>									
											<xsl:when test="substring(G29,1,2)='46'">
												<cat_ru:CustomsCountryCode>417</cat_ru:CustomsCountryCode>
											</xsl:when>									
										</xsl:choose>
									</catESAD_cu:BorderCustomsOffice>
								</xsl:if>	
								<ESADout_CUDepartureArrivalTransport>
									<cat_ru:TransportModeCode><xsl:value-of select="G261"/></cat_ru:TransportModeCode>
									<xsl:if  test="string-length(G212)>0">
										<cat_ru:TransportNationalityCode><xsl:value-of select="G212"/></cat_ru:TransportNationalityCode>
									</xsl:if>
									<xsl:choose>
										<xsl:when test="G261='30' and (count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS)>0]/NTRANS)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS1)>0]/NTRANS1)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS2)>0]/NTRANS2))>0">
											<TransportMeansQuantity><xsl:value-of select="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS)>0]/NTRANS)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS1)>0]/NTRANS1)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS2)>0]/NTRANS2)"/></TransportMeansQuantity>
										</xsl:when>
										<xsl:when test="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS)>0]/NTRANS)>0">
											<TransportMeansQuantity><xsl:value-of select="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS)>0]/NTRANS)"/></TransportMeansQuantity>
										</xsl:when>
									</xsl:choose>
									<xsl:for-each select="//DCL_TRANS/DCL_TRANS_ITEM[NGR='21' and string-length(NTRANS)>0]">
										<TransportMeans>
											<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:TransportIdentifier>
											<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G212"/></cat_ru:TransportMeansNationalityCode>
										</TransportMeans>
										<xsl:if test="string-length(NTRANS1)>0">
											<TransportMeans>
												<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS1"/></cat_ru:TransportIdentifier>
												<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G212"/></cat_ru:TransportMeansNationalityCode>
												<cat_ru:ActiveTransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:ActiveTransportIdentifier>
											</TransportMeans>
										</xsl:if>
										<xsl:if test="string-length(NTRANS2)>0">
											<TransportMeans>
												<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS2"/></cat_ru:TransportIdentifier>
												<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G212"/></cat_ru:TransportMeansNationalityCode>
												<cat_ru:ActiveTransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:ActiveTransportIdentifier>
											</TransportMeans>
										</xsl:if>
									</xsl:for-each>
								</ESADout_CUDepartureArrivalTransport>
								<ESADout_CUBorderTransport>
									<cat_ru:TransportModeCode><xsl:value-of select="G251"/></cat_ru:TransportModeCode>
									<xsl:if  test="string-length(G182)>0">
										<cat_ru:TransportNationalityCode><xsl:value-of select="G182"/></cat_ru:TransportNationalityCode>
									</xsl:if>	
									<xsl:choose>
										<xsl:when test="G261='30' and (count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS)>0]/NTRANS)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS1)>0]/NTRANS1)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS2)>0]/NTRANS2))>0">
											<TransportMeansQuantity><xsl:value-of select="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS)>0]/NTRANS)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS1)>0]/NTRANS1)+count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS2)>0]/NTRANS2)"/></TransportMeansQuantity>
										</xsl:when>
										<xsl:when test="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS)>0]/NTRANS)>0">
											<TransportMeansQuantity><xsl:value-of select="count(//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS)>0]/NTRANS)"/></TransportMeansQuantity>
										</xsl:when>
									</xsl:choose>
									<xsl:for-each select="//DCL_TRANS/DCL_TRANS_ITEM[NGR='18' and string-length(NTRANS)>0]">
										<TransportMeans>
											<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:TransportIdentifier>
											<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G182"/></cat_ru:TransportMeansNationalityCode>
										</TransportMeans>
										<xsl:if test="string-length(NTRANS1)>0">
											<TransportMeans>
												<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS1"/></cat_ru:TransportIdentifier>
												<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G182"/></cat_ru:TransportMeansNationalityCode>
												<cat_ru:ActiveTransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:ActiveTransportIdentifier>
											</TransportMeans>
										</xsl:if>
										<xsl:if test="string-length(NTRANS2)>0">
											<TransportMeans>
												<cat_ru:TransportIdentifier><xsl:value-of select="NTRANS2"/></cat_ru:TransportIdentifier>
												<cat_ru:TransportMeansNationalityCode><xsl:value-of select="G182"/></cat_ru:TransportMeansNationalityCode>
												<cat_ru:ActiveTransportIdentifier><xsl:value-of select="NTRANS"/></cat_ru:ActiveTransportIdentifier>
											</TransportMeans>
										</xsl:if>
									</xsl:for-each>
								</ESADout_CUBorderTransport>	
							</ESADout_CUConsigment>
							<ESADout_CUMainContractTerms>
								<catESAD_cu:ContractCurrencyCode><xsl:value-of select="G221"/></catESAD_cu:ContractCurrencyCode>
								<xsl:if  test="string-length(G23)>0">
									<catESAD_cu:ContractCurrencyRate><xsl:value-of select="format-number(G23,'0.00')"/></catESAD_cu:ContractCurrencyRate>
								</xsl:if>
								<xsl:if  test="string-length(G24_2)>0">
									<catESAD_cu:DealFeatureCode><xsl:value-of select="G24_2"/></catESAD_cu:DealFeatureCode>
								</xsl:if>
								<xsl:if  test="string-length(G24)>0">	
									<catESAD_cu:DealNatureCode><xsl:value-of select="G24"/></catESAD_cu:DealNatureCode>
								</xsl:if>	
								<catESAD_cu:TotalInvoiceAmount><xsl:value-of select="format-number(G222,'0.00')"/></catESAD_cu:TotalInvoiceAmount>
								<catESAD_cu:TradeCountryCode><xsl:value-of select="G11"/></catESAD_cu:TradeCountryCode>
								<xsl:if  test="string-length(G2021)>0 or string-length(G202)>0">
									<catESAD_cu:CUESADDeliveryTerms>
										<xsl:if  test="string-length(G2021)>0">
											<cat_ru:DeliveryPlace><xsl:value-of select="G2021"/></cat_ru:DeliveryPlace>
										</xsl:if>	
										<xsl:if  test="string-length(G202)>0">
											<cat_ru:DeliveryTermsStringCode><xsl:value-of select="G202"/></cat_ru:DeliveryTermsStringCode>
										</xsl:if>	
									</catESAD_cu:CUESADDeliveryTerms>
								</xsl:if>
							</ESADout_CUMainContractTerms>
							<xsl:for-each select="DCL_LOAD/DCL_LOAD_ITEM">
								<ESADout_CUGoods>
									<xsl:variable name="NumGood" select="position()"/>
									<catESAD_cu:GoodsNumeric><xsl:value-of select="position()"/></catESAD_cu:GoodsNumeric>
									<xsl:call-template name="GoodsDescr250">
										<xsl:with-param name="DesGoods" select="G31_1"/>
										<xsl:with-param name="NodeName" select="'catESAD_cu:GoodsDescription'"/>
										<xsl:with-param name="Namsp" select="'urn:customs.ru:CUESADCommonAggregateTypesCust:5.11.0'"/> 
										<xsl:with-param name="LenDes" select="250"/>											
									</xsl:call-template>	
									<catESAD_cu:GrossWeightQuantity><xsl:value-of select="round(G35 * 1000) div 1000"/></catESAD_cu:GrossWeightQuantity>
									<catESAD_cu:NetWeightQuantity><xsl:value-of select="round(G38 * 1000) div 100"/></catESAD_cu:NetWeightQuantity>
									<catESAD_cu:NetWeightQuantity2><xsl:value-of select="round(G38_2 * 1000) div 1000"/></catESAD_cu:NetWeightQuantity2>
									<catESAD_cu:InvoicedCost><xsl:value-of select="round(G42 * 100) div 100"/></catESAD_cu:InvoicedCost>
									<catESAD_cu:GoodsTNVEDCode><xsl:value-of select="substring(G33,1,10)"/></catESAD_cu:GoodsTNVEDCode>
									<catESAD_cu:OriginCountryCode><xsl:value-of select="G34"/></catESAD_cu:OriginCountryCode>
									<catESAD_cu:OriginCountryName><xsl:value-of select="G31_13"/></catESAD_cu:OriginCountryName>
									<xsl:if test="string-length(substring(G33,11,4))>0">
										<catESAD_cu:GoodsAddTNVEDCode><xsl:value-of select="substring(G33,11,4)"/></catESAD_cu:GoodsAddTNVEDCode>
									</xsl:if>
									<xsl:choose>
										<xsl:when test="$NumGood=1">
											<catESAD_cu:AdditionalSheetCount>1</catESAD_cu:AdditionalSheetCount>
										</xsl:when>
										<xsl:otherwise>
											<catESAD_cu:AdditionalSheetCount>
												<xsl:call-template name="NumList">
													<xsl:with-param name="Num" select="$NumGood"/>
												</xsl:call-template>	
											</catESAD_cu:AdditionalSheetCount>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:for-each select="DCL_LOAD_USLP/DCL_LOAD_USLP_ITEM">
										<catESAD_cu:CUESADDeliveryTerms>
											<cat_ru:DeliveryPlace><xsl:value-of select="G202t"/></cat_ru:DeliveryPlace>
											<cat_ru:DeliveryTermsStringCode><xsl:value-of select="G2021t"/></cat_ru:DeliveryTermsStringCode>
										</catESAD_cu:CUESADDeliveryTerms>
									</xsl:for-each>
									<xsl:for-each select="DCL_LOAD_ITEM/DCL_LOAD_ITEM_ITEM">
										<xsl:choose>
											<xsl:when test="string-length(ADDINFO)>1249">
												<xsl:variable name="BegT1">
													<xsl:call-template name="SplitTextBySpaceSp">
														<xsl:with-param name="Text" select="ADDINFO"/>
														<xsl:with-param name="Len" select="1249"/>
													</xsl:call-template>
												</xsl:variable>
												<xsl:call-template name="GoodsGr">
													<xsl:with-param name="AddText" select="$BegT1"/>
													<xsl:with-param name="FlgAllField" select="1"/>
												</xsl:call-template>
												<xsl:variable name="EndT1" select="substring(ADDINFO,string-length($BegT1)+1)"/>
												<xsl:if  test="string-length(normalize-space($EndT1))>0">
													<xsl:call-template name="GoodsGr">
														<xsl:with-param name="AddText" select="normalize-space($EndT1)"/>
													</xsl:call-template>
												</xsl:if>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="GoodsGr">
													<xsl:with-param name="AddText" select="ADDINFO"/>
													<xsl:with-param name="FlgAllField" select="1"/>
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:for-each>	
									<MilitaryProducts><xsl:value-of select="count(//DCL_LOAD_ITEM/DCL_LOAD_ITEM_ITEM[string-length(G31_10)>0]/G31_10)>0"/></MilitaryProducts>
									<CurrencyCode><xsl:value-of select="../../G221"/></CurrencyCode>
									<xsl:for-each select="DCL_LOAD_DOC/DCL_LOAD_DOC_ITEM">
										<ESADout_CUPresentedDocument>
											<cat_ru:PrDocumentName><xsl:value-of select="G444"/></cat_ru:PrDocumentName>
											<cat_ru:PrDocumentNumber><xsl:value-of select="G442"/></cat_ru:PrDocumentNumber>
											<xsl:if test="string-length(G443)>0">
												<cat_ru:PrDocumentDate><xsl:value-of select="substring(G443,1,10)"/></cat_ru:PrDocumentDate>
											</xsl:if>
											<catESAD_cu:PresentedDocumentModeCode><xsl:value-of select="G441"/></catESAD_cu:PresentedDocumentModeCode>
											<xsl:if test="string-length(G446)>0">
												<catESAD_cu:DocumentBeginActionsDate><xsl:value-of select="substring(G446,1,10)"/></catESAD_cu:DocumentBeginActionsDate>
											</xsl:if>
											<xsl:if test="string-length(G447)>0">
												<catESAD_cu:DocumentEndActionsDate><xsl:value-of select="substring(G447,1,10)"/></catESAD_cu:DocumentEndActionsDate>
											</xsl:if>	
											<catESAD_cu:CountryCode><xsl:value-of select="G445COUNTRYCODE"/></catESAD_cu:CountryCode>
										</ESADout_CUPresentedDocument>
									</xsl:for-each>
									<xsl:if test="string-length(G31_7)>0">
										<SupplementaryGoodsQuantity>
											<cat_ru:GoodsQuantity><xsl:value-of select="G31_7"/></cat_ru:GoodsQuantity>
											<xsl:if test="string-length(G31_71)>0">
												<cat_ru:MeasureUnitQualifierName><xsl:value-of select="G31_71"/></cat_ru:MeasureUnitQualifierName>
											</xsl:if>
											<xsl:if test="string-length(G41A)>0">
												<cat_ru:MeasureUnitQualifierCode><xsl:value-of select="G41A"/></cat_ru:MeasureUnitQualifierCode>
											</xsl:if>	
										</SupplementaryGoodsQuantity>	
									</xsl:if>
									<xsl:if test="string-length(G31_8)>0">
										<SupplementaryGoodsQuantity1>
											<cat_ru:GoodsQuantity><xsl:value-of select="format-number(G31_8,'#.##')"/></cat_ru:GoodsQuantity>
											<xsl:if test="string-length(G31_81)>0">
												<cat_ru:MeasureUnitQualifierName><xsl:value-of select="G31_81"/></cat_ru:MeasureUnitQualifierName>
											</xsl:if>
											<xsl:if test="string-length(G31_82)>0">
												<cat_ru:MeasureUnitQualifierCode><xsl:value-of select="G31_82"/></cat_ru:MeasureUnitQualifierCode>
											</xsl:if>	
										</SupplementaryGoodsQuantity1>	
									</xsl:if>
									<xsl:if test="string-length(PackCountFull)>0 or string-length(G31_20)>0 or string-length(PackCountPart)>0">
										<ESADGoodsPackaging>
											<xsl:if test="string-length(PackCountFull)>0">
												<catESAD_cu:PakageQuantity><xsl:value-of select="PackCountFull"/></catESAD_cu:PakageQuantity>
											</xsl:if>	
											<xsl:if test="string-length(G31_20)>0">
												<catESAD_cu:PakageTypeCode><xsl:value-of select="G31_20"/></catESAD_cu:PakageTypeCode>
											</xsl:if>	
											<xsl:if test="string-length(PackCountPart)>0">
												<catESAD_cu:PakagePartQuantity><xsl:value-of select="PackCountPart"/></catESAD_cu:PakagePartQuantity>
											</xsl:if>	
											<xsl:for-each select="DCL_LOAD_PACK/DCL_LOAD_PACK_ITEM[PKSIGN=0]">
												<catESAD_cu:PackingInformation>
													<PackingCode><xsl:value-of select="PACK_CODE"/></PackingCode>
													<PakingQuantity><xsl:value-of select="PACK_QUANT"/></PakingQuantity>
												</catESAD_cu:PackingInformation>
											</xsl:for-each>
											<xsl:for-each select="DCL_LOAD_PACK/DCL_LOAD_PACK_ITEM[PKSIGN=3]">
												<catESAD_cu:PalleteInformation>
													<PackingCode><xsl:value-of select="PACK_CODE"/></PackingCode>
													<PakingQuantity><xsl:value-of select="PACK_QUANT"/></PakingQuantity>
												</catESAD_cu:PalleteInformation>
											</xsl:for-each>
											<xsl:for-each select="DCL_LOAD_PACK/DCL_LOAD_PACK_ITEM[PKSIGN=1]">
												<catESAD_cu:UnitPackInfo>
													<PackingCode><xsl:value-of select="PACK_CODE"/></PackingCode>
													<PakingQuantity><xsl:value-of select="PACK_QUANT"/></PakingQuantity>
												</catESAD_cu:UnitPackInfo>
											</xsl:for-each>
											<xsl:for-each select="DCL_LOAD_PACK/DCL_LOAD_PACK_ITEM[PKSIGN=2]">
												<catESAD_cu:CargoInfo>
													<PackingCode><xsl:value-of select="PACK_CODE"/></PackingCode>
													<PakingQuantity><xsl:value-of select="PACK_QUANT"/></PakingQuantity>
												</catESAD_cu:CargoInfo>
											</xsl:for-each>
										</ESADGoodsPackaging>
									</xsl:if>
									<xsl:if test="count(//DCL_LOAD_CONT/DCL_LOAD_CONT_ITEM[string-length(cont_num)>0])>0">
										<ESADContainer>
											<catESAD_cu:ContainerQuantity><xsl:value-of select="count(//DCL_LOAD_CONT/DCL_LOAD_CONT_ITEM[string-length(cont_num)>0])"/></catESAD_cu:ContainerQuantity>
											<catESAD_cu:ContainerKind><xsl:value-of select="//DCL_LOAD_CONT/DCL_LOAD_CONT_ITEM[string-length(cont_num)>0 and position()=1]/CONT_CODE"/></catESAD_cu:ContainerKind>
											<xsl:for-each select="DCL_LOAD_CONT/DCL_LOAD_CONT_ITEM[string-length(cont_num)>0]">
												<catESAD_cu:ContainerNumber>
													<catESAD_cu:ContainerIdentificaror><xsl:value-of select="CONT_NUM"/></catESAD_cu:ContainerIdentificaror>
													<catESAD_cu:FullIndicator><xsl:value-of select="CONT_TYPE"/></catESAD_cu:FullIndicator>
												</catESAD_cu:ContainerNumber>
											</xsl:for-each>	
										</ESADContainer>
									</xsl:if>
									<xsl:if test="string-length(G37)>0">
										<ESADCustomsProcedure>
											<catESAD_cu:MainCustomsModeCode><xsl:value-of select="substring(G37,1,2)"/></catESAD_cu:MainCustomsModeCode>
											<catESAD_cu:PrecedingCustomsModeCode><xsl:value-of select="substring(G37,3,2)"/></catESAD_cu:PrecedingCustomsModeCode>
											<catESAD_cu:GoodsTransferFeature><xsl:value-of select="substring(G37,5,3)"/></catESAD_cu:GoodsTransferFeature>
										</ESADCustomsProcedure>
									</xsl:if>	
								</ESADout_CUGoods>			
							</xsl:for-each>	
						</ESADout_CUGoodsShipment>
					</ESADout_CU>
				</DocBody>
			</ContainerDoc>		
		</ED_Container>			
  </xsl:template>	
    
</xsl:stylesheet>
